<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 11/16/2003 *
 * ===============                              Last change: 12/13/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : mysql-connect.php                                *
 * -------------------------------------------------------------------- *
 * Short description : Connects to your database                        *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Verbindet zu Ihrer Datenbank                     *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
}

// CFG: DEBUG-SQL (if enabled and DEBUG_MODE is enabled all SQL queries will be logged to debug.log)
define('DEBUG_SQL', false);

// Default is not a frameset
global $isFrameset;
$isFrameset = false;

// Load library
require_once(PATH."inc/db/lib.php");

// Load general functions
require_once(PATH."inc/functions.php");  // Non-database functions

// Load more include files
require_once(PATH."inc/mysql-manager.php"); // Functions which interact with the database

// Load extensions and language
require_once(PATH."inc/extensions.php");
require_once(PATH."inc/language.php");

// Init error handler
function __errorHandler ($errno, $errstr, $errfile, $errline) {
	$msg = sprintf("errno=%s,errstr=%s,errfile=%s,errline=%s",
		$errno,
		$errstr,
		basename($errfile),
		$errline
	);
	DEBUG_LOG(__FUNCTION__.":".$msg, true);
	print "Please report this error at <a href=\"http://forum.mxchange.org\" target=\"_blank\">forum.mxchange.org</a>:<pre>";
	debug_print_backtrace();
	die("</pre>Thanks for your help finding bugs.");
}

// Set error handler
set_error_handler('__errorHandler');

// Check if the user setups his MySQL stuff...
if ((empty($MySQL['login'])) && (!defined('mxchange_installing')) && (!isset($_GET['installing'])) && (isBooleanConstantAndTrue('mxchange_installed'))) {
	// No login entered and outside installation mode
	echo "<STRONG>".LANG_WARNING.":</STRONG> ";
	if (isBooleanConstantAndTrue('mxchange_installed')) {
		// You have changed my configuration file!
		die(DIE_CONFIG_CHANGED_YOU);
	} else {
		// Please run the installation script (maybe again)
		die(DIE_RUN_INSTALL_MYSQL);
	}
} elseif ((!defined('mxchange_installing')) && (!isset($_GET['installing'])) && (empty($MySQL['password'])) && (isBooleanConstantAndTrue('warn_no_pass'))) {
	// No database password entered!!!
	echo "<STRONG>".LANG_WARNING.":</STRONG> ".WARN_NULL_PASSWORD;
}

// Check if this file is writeable or read-only and warn the user
if ((!isBooleanConstantAndTrue('mxchange_installing')) && (isBooleanConstantAndTrue('mxchange_installed'))) {
	// Check for write-permission for config.php and inc directory
	if (empty($GLOBALS['module'])) $GLOBALS['module'] = "index";

	// CSS array
	$EXT_CSS_FILES = array();

	if ((!empty($MySQL['host'])) && (!empty($MySQL['login'])) && (!empty($MySQL['password'])) && (!empty($MySQL['dbase']))) {
		// Connect to DB
		global $link;
		$link = SQL_CONNECT($MySQL['host'], $MySQL['login'], $MySQL['password'], __FILE__, __LINE__);

		// Is the link valid?
		if (is_resource($link)) {
			// Choose the database
			global $db;
			$db = SQL_SELECT_DB($MySQL['dbase'], $link, __FILE__, __LINE__);

			// Is it a valid resource?
			if ($db === true) {
				// Remove MySQL array from namespace
				unset($MySQL);

				// Load configuration stuff
				$_CONFIG = LOAD_CONFIG();

				// Initialize include-file-pool
				$INC_POOL = array();

				// Load "databases" aka static arrays
				require_once(PATH."inc/databases.php");

				// Loading patching system is required here...
				require_once(PATH."inc/patch-system.php"); // Initialize patch system

				// Functions which are related to themes
				require_once(PATH."inc/theme-manager.php");

				// Run daily reset
				require_once(PATH."inc/check-reset.php");

				// Load admin include file if he is admin
				if (IS_ADMIN()) {
					// Administrative functions
					require_once(PATH."inc/modules/admin/admin-inc.php");
				} // END - if

				// Get all values
				if (($CSS != 1) && ($CSS != -1)) {
					if (empty($GLOBALS['module']))  $GLOBALS['module'] = "empty";
					if (empty($GLOBALS['what']))    $GLOBALS['what']   = GET_WHAT($GLOBALS['module']);
					if (empty($GLOBALS['action']))  $GLOBALS['action'] = GET_ACTION($GLOBALS['module'], $GLOBALS['what']);
				} else {
					// Set action/what to empty
					$GLOBALS['action'] = "";
					$GLOBALS['what']   = "";
				}

				// Secure and validate user ID from cookie
				UPDATE_LOGIN_DATA();

				// Update online list
				UPDATE_ONLINE_LIST($PHPSESSID, $GLOBALS['module'], $GLOBALS['action'], $GLOBALS['what']);

				// Set default 'what' value
				//* DEBUG */ echo "-".$GLOBALS['module']."/".$GLOBALS['what']."-<br />\n";
				if ((empty($GLOBALS['what'])) && (empty($GLOBALS['action'])) && ($CSS != 1) && ($CSS != -1)) {
					if ($GLOBALS['module'] == "admin") {
						// Set 'action' value to 'login' in admin menu
						$GLOBALS['action'] = GET_ACTION($GLOBALS['module'], $GLOBALS['what']);
					} elseif (($GLOBALS['module'] == "index") || ($GLOBALS['module'] == "login")) {
						// Set 'what' value to 'welcome' in guest and member menu
						$GLOBALS['what'] = "welcome";
						if (!empty($_CONFIG['index_home'])) $GLOBALS['what'] = $_CONFIG['index_home'];
					} else {
						// Anything else like begging link
						$GLOBALS['what'] = "";
					}
				} // END - if

				// Update sending pool
				if (($CSS != "1") && ($CSS != "-1")) require_once(PATH."inc/pool-update.php"); // Sends out mails in configureable steps

				// Load all active extension including language files when not upgrading.
				// Check module for testing and count one click
				$dummy = CHECK_MODULE($GLOBALS['module']);
				if ($dummy == "done") COUNT_MODULE($GLOBALS['module']);
				unset($dummy);

				// Shall we activate the exchange?
				if ($_CONFIG['activate_xchange'] > 0) activateExchange();

				// Is the extension sql_patches installed and at least 0.3.6?
				if (GET_EXT_VERSION("sql_patches") >= "0.3.6") {
					// Generate random number
					if (isset($GLOBALS['userid'])) {
						define('RAND_NUMBER', GEN_RANDOM_CODE(10, mt_rand(10000,32766), $GLOBALS['userid'], ""));
					} else {
						define('RAND_NUMBER', GEN_RANDOM_CODE(10, mt_rand(10000,32766), 0, ""));
					}
				} else {
					// Generate weak (!!!) code
					define('RAND_NUMBER', mt_rand(1000000, 9999999));
				}
			} else {
				// Wrong database?
				ADD_FATAL(WRONG_DB_SELECTED);
			}
		} else {
			// No link to database!
			ADD_FATAL(NO_DB_LINK);
			$db = false;
		}
	} else {
		// Maybe you forgot to enter your MySQL data?
		ADD_FATAL(MYSQL_DATA_MISSING);
	}
} else {
	///////////////////////////////////////////////////
	// Include neccessary functions for installation //
	///////////////////////////////////////////////////

	// Set CONFIG array
	$_CONFIG = array(
		'code_length' => 0
	);

	// Set other missing variables
	$link = false; // No database link by default

	// Include required files
	require_once(PATH."inc/databases.php");
	require_once(PATH."inc/theme-manager.php");

	// Check if we are in installation routine
	$installPhp = basename($_SERVER['PHP_SELF']);
	if (($installPhp != "install.php") && ($CSS != "1") && ($CSS != -1)) {
		// Redirect to the installation system
		LOAD_URL("install.php");
	} // END - if

	// Double-check installation mode
	if ((!isBooleanConstantAndTrue('mxchange_installed')) || (!isBooleanConstantAndTrue('admin_registered'))) {
		// Check for file permissions
		if (!is_INCWritable("config")) {
			ADD_FATAL(CONFIG_IS_WRITE_PROTECTED);
		}
		if (!is_INCWritable("dummy")) {
			ADD_FATAL(DUMMY_IS_WRITE_PROTECTED);
		}
		if (!is_INCWritable(".secret/dummy")) {
			ADD_FATAL(SECRET_IS_WRITE_PROTECTED);
		}
	} // END - if
}

// Any fatal messages?
if (!is_array($FATAL)) $FATAL = array();
if (((sizeof($FATAL) > 0) || (!empty($FATAL[0]))) && (isBooleanConstantAndTrue('mxchange_installed')) && (!defined('mxchange_installing')) && ($CSS != "1"))
{
	// One or more fatal error(s) occur during connect...
	include (PATH."inc/header.php");
	include (PATH."inc/fatal_errors.php");
	unset($FATAL);
	include (PATH."inc/footer.php");
	exit;
}

//
?>
